BatchOptions

Struct BatchOptions 

pub struct BatchOptions { /* private fields */ }
Options for batch operations.

BatchOptions controls batch behavior. Shell operation timeout is supplied by crate::manager::QuickAccessManager configuration rather than this type.

Examples

use wincent::BatchOptions;

let options = BatchOptions::new().refresh_recent_files();

assert!(options.force_update());

Implementations

Source

impl BatchOptions

pub fn new() -> Self

Creates default batch options.

pub fn force_update(&self) -> bool

Whether Recent Files display data is refreshed after successful additions.

pub fn with_force_update(self, force_update: bool) -> Self

Sets whether Recent Files display data is refreshed after successful additions.

pub fn refresh_recent_files(self) -> Self

Refreshes Recent Files display data after successful additions.