EmptyOptions

Struct EmptyOptions 

pub struct EmptyOptions { /* private fields */ }
Options for clearing Quick Access items.

By default, clearing Frequent Folders removes user-visited frequent folders but leaves pinned folders alone. Use EmptyOptions::remove_pinned_folders only when the caller explicitly wants to unpin user-pinned folders too.

Examples

use wincent::EmptyOptions;

let options = EmptyOptions::new()
    .remove_pinned_folders()
    .refresh_explorer();

assert!(options.also_pinned_folders());
assert!(options.force_refresh());

Implementations

Source

impl EmptyOptions

pub fn new() -> Self

Creates default clear options.

pub fn also_pinned_folders(&self) -> bool

Whether pinned folders should also be removed.

pub fn with_also_pinned_folders(self, also_pinned_folders: bool) -> Self

Sets whether pinned folders should also be removed.

pub fn remove_pinned_folders(self) -> Self

Also removes pinned folders when clearing Frequent Folders or all items.

pub fn force_refresh(&self) -> bool

Whether open Explorer windows should be refreshed after a successful clear.

pub fn with_force_refresh(self, force_refresh: bool) -> Self

Sets whether open Explorer windows should be refreshed after a successful clear.

pub fn refresh_explorer(self) -> Self

Refreshes open Explorer windows after a successful clear.