pub struct BatchOptions { /* private fields */ }Expand description
Options for batch operations.
BatchOptions controls batch behavior. Shell operation timeout is supplied
by crate::manager::QuickAccessManager configuration rather than this
type.
Examples
use wincent::BatchOptions;
let options = BatchOptions::new().refresh_recent_files();
assert!(options.force_update());Implementations
Sourceimpl BatchOptions
impl BatchOptions
Sourcepub fn force_update(&self) -> bool
pub fn force_update(&self) -> bool
Whether Recent Files display data is refreshed after successful additions.
Sourcepub fn with_force_update(self, force_update: bool) -> Self
pub fn with_force_update(self, force_update: bool) -> Self
Sets whether Recent Files display data is refreshed after successful additions.
Sourcepub fn refresh_recent_files(self) -> Self
pub fn refresh_recent_files(self) -> Self
Refreshes Recent Files display data after successful additions.